@@ -12,8 +12,8 @@ use console::Term;
 use dialoguer::{theme, Confirm, Input};
 use itertools::Itertools;
 use serde::{de, Deserialize, Serialize};
+use structopt::clap;
 use structopt::StructOpt;
-// use structopt::clap;
 
 use crate::api;
 use crate::k8s;
@@ -266,7 +266,7 @@ enum Command {
         about = "Create new namespace",
         aliases = &["cns", "c-ns", "create-ns"],
         display_order(1000),
-        // setting(clap::AppSettings::Hidden)
+        setting(clap::AppSettings::Hidden)
     )]
     CreateNamespace {
         #[structopt(help = "Namespace name", default_value = "statehub-system")]
@@ -277,7 +277,7 @@ enum Command {
         about = "Save cluster token",
         alias = "sct",
         display_order(1000),
-        // setting(clap::AppSettings::Hidden)
+        setting(clap::AppSettings::Hidden)
     )]
     SaveClusterToken {
         #[structopt(help = "Namespace name")]
@@ -290,7 +290,7 @@ enum Command {
         about = "Setup statehub configmap",
         aliases = &["scm", "setup-cm"],
         display_order(1000),
-        // setting(clap::AppSettings::Hidden)
+        setting(clap::AppSettings::Hidden)
     )]
     SetupConfigmap {
         #[structopt(help = "cluster name")]
@@ -310,25 +310,29 @@ enum Command {
         about = "List K8s namespaces",
         alias = "list-ns",
         display_order(1000),
-        // setting(clap::AppSettings::Hidden)
+        setting(clap::AppSettings::Hidden)
     )]
     ListNamespaces,
 
     #[structopt(
         about = "List K8s nodes",
         display_order(1000),
-        // setting(clap::AppSettings::Hidden)
+        setting(clap::AppSettings::Hidden)
     )]
     ListNodes,
 
     #[structopt(
         about = "List K8s pods",
         display_order(1000),
-        // setting(clap::AppSettings::Hidden)
+        setting(clap::AppSettings::Hidden)
     )]
     ListPods,
 
-    #[structopt(about = "List K8s node regions", aliases = &["list-r", "lr"], display_order(1000))]
+    #[structopt(
+        about = "List K8s node regions",
+        aliases = &["list-r", "lr"], display_order(1000),
+        setting(clap::AppSettings::Hidden),
+    )]
     ListRegions {
         #[structopt(help = "Also list zones", long, short)]
         zone: bool,
